@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 using System;
 using System.Collections.Generic;
 using System.Text;
+using System.ComponentModel;
 
 namespace KeePass.App.Configuration
 {
@@ -30,6 +31,7 @@ namespace KeePass.App.Configuration
 		}
 
 		private bool m_bOnlyIfTrayed = false;
+		[DefaultValue(false)]
 		public bool ShowOnlyIfTrayed
 		{
 			get { return m_bOnlyIfTrayed; }
@@ -37,6 +39,7 @@ namespace KeePass.App.Configuration
 		}
 
 		private bool m_bSingleClickDefault = false;
+		[DefaultValue(false)]
 		public bool SingleClickDefault
 		{
 			get { return m_bSingleClickDefault; }
