@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -140,7 +140,7 @@ namespace KeePass.Forms
 		{
 			if(m_ilIcons != null)
 			{
-				m_lvInfo.SmallImageList = null;
+				m_lvInfo.SmallImageList = null; // Detach event handlers
 				m_ilIcons.Dispose();
 				m_ilIcons = null;
 			}
