@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@ namespace KeePass.Native
 
 		internal const int WM_NOTIFY = 0x004E;
 
+		internal const int WM_GETTEXTLENGTH = 0x000E;
 		internal const int WM_GETICON = 0x007F;
 
 		internal const int HWND_BROADCAST = 0xFFFF;
@@ -287,5 +288,48 @@ namespace KeePass.Native
 			SIF_TRACKPOS = 0x10,
 			SIF_ALL = SIF_RANGE + SIF_PAGE + SIF_POS + SIF_TRACKPOS
 		}
+
+		[Flags]
+		internal enum MessageBoxFlags : uint
+		{
+			// Buttons
+			MB_ABORTRETRYIGNORE = 0x00000002,
+			MB_CANCELTRYCONTINUE = 0x00000006,
+			MB_HELP = 0x00004000,
+			MB_OK = 0,
+			MB_OKCANCEL = 0x00000001,
+			MB_RETRYCANCEL = 0x00000005,
+			MB_YESNO = 0x00000004,
+			MB_YESNOCANCEL = 0x00000003,
+
+			// Icons
+			MB_ICONEXCLAMATION = 0x00000030,
+			MB_ICONWARNING = 0x00000030,
+			MB_ICONINFORMATION = 0x00000040,
+			MB_ICONASTERISK = 0x00000040,
+			MB_ICONQUESTION = 0x00000020,
+			MB_ICONSTOP = 0x00000010,
+			MB_ICONERROR = 0x00000010,
+			MB_ICONHAND = 0x00000010,
+
+			// Default buttons
+			MB_DEFBUTTON1 = 0,
+			MB_DEFBUTTON2 = 0x00000100,
+			MB_DEFBUTTON3 = 0x00000200,
+			MB_DEFBUTTON4 = 0x00000300,
+
+			// Modality
+			MB_APPLMODAL = 0,
+			MB_SYSTEMMODAL = 0x00001000,
+			MB_TASKMODAL = 0x00002000,
+
+			// Other options
+			MB_DEFAULT_DESKTOP_ONLY = 0x00020000,
+			MB_RIGHT = 0x00080000,
+			MB_RTLREADING = 0x00100000,
+			MB_SETFOREGROUND = 0x00010000,
+			MB_TOPMOST = 0x00040000,
+			MB_SERVICE_NOTIFICATION = 0x00200000
+		}
 	}
 }
