@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -81,7 +81,8 @@ namespace KeePass
 			IpcByFile = 3,
 			AutoType = 4,
 			Lock = 5,
-			Unlock = 6
+			Unlock = 6,
+			AutoTypeSelected = 7
 		}
 
 		public static CommandLineArgs CommandLineArgs
@@ -347,6 +348,11 @@ namespace KeePass
 				BroadcastAppMessageAndCleanUp(AppMessage.AutoType);
 				return;
 			}
+			else if(m_cmdLineArgs[AppDefs.CommandLineOptions.AutoTypeSelected] != null)
+			{
+				BroadcastAppMessageAndCleanUp(AppMessage.AutoTypeSelected);
+				return;
+			}
 			else if(m_cmdLineArgs[AppDefs.CommandLineOptions.OpenEntryUrl] != null)
 			{
 				string strEntryUuid = m_cmdLineArgs[AppDefs.CommandLineOptions.Uuid];
