@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -191,7 +191,7 @@ namespace KeePass.Util
 			}
 
 			pweData.Touch(false);
-			if(EntryUtil.ExpireTanEntryIfOption(pweData))
+			if(EntryUtil.ExpireTanEntryIfOption(pweData, pwDatabase))
 				Program.MainForm.RefreshEntriesList();
 
 			// SprEngine.Compile might have modified the database;
