@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -102,8 +102,14 @@ namespace KeePassLib.Cryptography
 			m_sBaseStream.Flush();
 		}
 
+#if KeePassRT
+		protected override void Dispose(bool disposing)
+		{
+			if(!disposing) return;
+#else
 		public override void Close()
 		{
+#endif
 			if(m_hash != null)
 			{
 				try
