@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -868,7 +868,13 @@ namespace KeePassLib
 			string strB = b.Strings.ReadSafe(m_strFieldName);
 
 			if(m_bCompareNaturally) return StrUtil.CompareNaturally(strA, strB);
+
+#if KeePassRT
+			return string.Compare(strA, strB, m_bCaseInsensitive ?
+				StringComparison.CurrentCultureIgnoreCase : StringComparison.CurrentCulture);
+#else
 			return string.Compare(strA, strB, m_bCaseInsensitive);
+#endif
 		}
 	}
 }
