@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2011 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,7 +60,6 @@ namespace KeePassLib
 		PreOrder = 1
 	}
 
-#pragma warning disable 1591 // Missing XML comments warning
 	/// <summary>
 	/// Methods for merging password databases/entries.
 	/// </summary>
@@ -73,9 +72,7 @@ namespace KeePassLib
 		CreateNewUuids = 4,
 		Synchronize = 5
 	}
-#pragma warning restore 1591 // Missing XML comments warning
 
-#pragma warning disable 1591 // Missing XML comments warning
 	/// <summary>
 	/// Icon identifiers for groups and password entries.
 	/// </summary>
@@ -156,7 +153,6 @@ namespace KeePassLib
 		/// </summary>
 		Count
 	}
-#pragma warning restore 1591 // Missing XML comments warning
 
 	public enum ProxyServerType
 	{
@@ -164,4 +160,88 @@ namespace KeePassLib
 		System = 1,
 		Manual = 2
 	}
+
+	/// <summary>
+	/// Comparison modes for in-memory protected objects.
+	/// </summary>
+	public enum MemProtCmpMode
+	{
+		/// <summary>
+		/// Ignore the in-memory protection states.
+		/// </summary>
+		None = 0,
+
+		/// <summary>
+		/// Ignore the in-memory protection states of standard
+		/// objects; do compare in-memory protection states of
+		/// custom objects.
+		/// </summary>
+		CustomOnly,
+
+		/// <summary>
+		/// Compare in-memory protection states.
+		/// </summary>
+		Full
+	}
+
+	[Flags]
+	public enum PwCompareOptions
+	{
+		None = 0x0,
+
+		/// <summary>
+		/// Empty standard string fields are considered to be the
+		/// same as non-existing standard string fields.
+		/// This doesn't affect custom string comparisons.
+		/// </summary>
+		NullEmptyEquivStd = 0x1,
+
+		IgnoreParentGroup = 0x2,
+		IgnoreLastAccess = 0x4,
+		IgnoreLastMod = 0x8,
+		IgnoreHistory = 0x10,
+		IgnoreLastBackup = 0x20,
+
+		IgnoreTimes = (IgnoreLastAccess | IgnoreLastMod)
+	}
+
+	public enum IOAccessType
+	{
+		None = 0,
+
+		/// <summary>
+		/// The IO connection is being opened for reading.
+		/// </summary>
+		Read = 1,
+
+		/// <summary>
+		/// The IO connection is being opened for writing.
+		/// </summary>
+		Write = 2,
+
+		/// <summary>
+		/// The IO connection is being opened for testing
+		/// whether a file/object exists.
+		/// </summary>
+		Exists = 3,
+
+		/// <summary>
+		/// The IO connection is being opened for deleting a file/object.
+		/// </summary>
+		Delete = 4,
+
+		/// <summary>
+		/// The IO connection is being opened for renaming/moving a file/object.
+		/// </summary>
+		Move = 5
+	}
+
+	// public enum PwLogicalOp
+	// {
+	//	None = 0,
+	//	Or = 1,
+	//	And = 2,
+	//	NOr = 3,
+	//	NAnd = 4
+	// }
 }
