@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ namespace KeePassLib.Serialization
 	public sealed class BinaryReaderEx
 	{
 		private Stream m_s;
-		private Encoding m_enc;
+		// private Encoding m_enc; // See constructor
 
 		private string m_strReadExcp;
 		public string ReadExceptionText
@@ -56,7 +56,7 @@ namespace KeePassLib.Serialization
 			if(input == null) throw new ArgumentNullException("input");
 
 			m_s = input;
-			m_enc = encoding;
+			// m_enc = encoding; // Not used yet
 			m_strReadExcp = strReadExceptionText;
 		}
 
