@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2012 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 */
 
 using System;
+using System.Collections.Generic;
 using System.Text;
 using System.Security.Cryptography;
 using System.Diagnostics;
@@ -394,11 +395,81 @@ namespace KeePassLib.Utility
 			if(v == null) throw new ArgumentNullException("v");
 			if(iOffset < 0) throw new ArgumentOutOfRangeException("iOffset");
 			if(iLength < 0) throw new ArgumentOutOfRangeException("iLength");
-			if(iOffset + iLength > v.Length) throw new ArgumentException();
+			if((iOffset + iLength) > v.Length) throw new ArgumentException();
 
 			T[] r = new T[iLength];
 			Array.Copy(v, iOffset, r, 0, iLength);
 			return r;
 		}
+
+		public static IEnumerable<T> Union<T>(IEnumerable<T> a, IEnumerable<T> b,
+			IEqualityComparer<T> cmp)
+		{
+			if(a == null) throw new ArgumentNullException("a");
+			if(b == null) throw new ArgumentNullException("b");
+
+			Dictionary<T, bool> d = ((cmp != null) ?
+				(new Dictionary<T, bool>(cmp)) : (new Dictionary<T, bool>()));
+
+			foreach(T ta in a)
+			{
+				if(d.ContainsKey(ta)) continue; // Prevent duplicates
+
+				d[ta] = true;
+				yield return ta;
+			}
+
+			foreach(T tb in b)
+			{
+				if(d.ContainsKey(tb)) continue; // Prevent duplicates
+
+				d[tb] = true;
+				yield return tb;
+			}
+
+			yield break;
+		}
+
+		public static IEnumerable<T> Intersect<T>(IEnumerable<T> a, IEnumerable<T> b,
+			IEqualityComparer<T> cmp)
+		{
+			if(a == null) throw new ArgumentNullException("a");
+			if(b == null) throw new ArgumentNullException("b");
+
+			Dictionary<T, bool> d = ((cmp != null) ?
+				(new Dictionary<T, bool>(cmp)) : (new Dictionary<T, bool>()));
+
+			foreach(T tb in b) { d[tb] = true; }
+
+			foreach(T ta in a)
+			{
+				if(d.Remove(ta)) // Prevent duplicates
+					yield return ta;
+			}
+
+			yield break;
+		}
+
+		public static IEnumerable<T> Except<T>(IEnumerable<T> a, IEnumerable<T> b,
+			IEqualityComparer<T> cmp)
+		{
+			if(a == null) throw new ArgumentNullException("a");
+			if(b == null) throw new ArgumentNullException("b");
+
+			Dictionary<T, bool> d = ((cmp != null) ?
+				(new Dictionary<T, bool>(cmp)) : (new Dictionary<T, bool>()));
+
+			foreach(T tb in b) { d[tb] = true; }
+
+			foreach(T ta in a)
+			{
+				if(d.ContainsKey(ta)) continue;
+
+				d[ta] = true; // Prevent duplicates
+				yield return ta;
+			}
+
+			yield break;
+		}
 	}
 }
